/******************************************************************************/
/* SISTEMAS INTEGRADOS TECNISA                                                */
/*                                                                            */
/* COMPRAS E SUPRIMENTOS                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* NOME: GRAVA_LOGITEMCOLE                                                    */
/*                                                                            */
/* DESCRIO:                                                                 */
/*   Grava log de item de cotao                                             */
/*                                                                            */
/* CRIAO:                                                                   */
/* 24/12/2003 - Adriano de Arajo                                             */
/*                                                                            */
/******************************************************************************/

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'GRAVA_LOGITEMCOLE'  and
            type = 'TR'                 and
            u.uid = o.uid               and
            u.name = USER)
  DROP TRIGGER GRAVA_LOGITEMCOLE
  GO

CREATE TRIGGER GRAVA_LOGITEMCOLE
ON ITEMCOLE
FOR INSERT, UPDATE, DELETE

AS

/* Variveis do cursor */
DECLARE @V_IDCOMANDO     VARCHAR(01);
DECLARE @V_CDFILIAL      VARCHAR(04);
DECLARE @V_NRCOLEPRECO   VARCHAR(10);
DECLARE @V_CDMARCA       VARCHAR(05);
DECLARE @V_CDREGIAO      VARCHAR(03);
DECLARE @V_CDFORNECED    VARCHAR(21);
DECLARE @V_CDPRODUTO     VARCHAR(10);
DECLARE @V_DTINIVALITM   DATETIME;
DECLARE @V_DTFINVALITM   DATETIME;
DECLARE @V_NEW_VRPRECUNIITM  DOUBLE PRECISION;
DECLARE @V_OLD_VRPRECUNIITM  DOUBLE PRECISION;
DECLARE @V_IDITMLISPREC  VARCHAR(01);
DECLARE @V_NRCOLEORIGIC  VARCHAR(10);
DECLARE @V_DTINCLITMCOL  DATETIME;
DECLARE @V_IDATUREGIINC  VARCHAR(01);
DECLARE @V_IDATUREGIALT  VARCHAR(01);
DECLARE @V_CDOPERINCL    VARCHAR(12);
DECLARE @V_IDATUFORNINC  VARCHAR(01);
DECLARE @V_IDATUFORNALT  VARCHAR(01);


DECLARE @V_IDGRAVLOGCOT  VARCHAR(03);
DECLARE @V_DSREMOTEADDR  VARCHAR(50);
DECLARE @V_DSREMOTEHOST  VARCHAR(50);
DECLARE @V_DSSERVERRDM   VARCHAR(50);
DECLARE @V_DSMETUSULIC   VARCHAR(50);
DECLARE @V_CDOPERLIC     VARCHAR(12);

BEGIN

   DECLARE C_DADOS CURSOR FOR
     SELECT
       'D' IDCOMANDO,
       CDFILIAL,
       NRCOLEPRECO,
       CDMARCA,
       CDREGIAO,
       CDFORNECED,
       CDPRODUTO,
       DTINIVALITM,
       DTFINVALITM,
       VRPRECUNIITM,
       VRPRECUNIITM,
       IDITMLISPREC,
       NRCOLEORIGIC,
       DTINCLITMCOL,
       IDATUREGIINC,
       IDATUREGIALT,
       CDOPERINCL,
       IDATUFORNINC,
       IDATUFORNALT
     FROM
       DELETED
     WHERE
       0 = (SELECT COUNT(*) FROM INSERTED)

     UNION ALL

     SELECT
       'U' IDCOMANDO,
       INSERTED.CDFILIAL,
       INSERTED.NRCOLEPRECO,
       INSERTED.CDMARCA,
       INSERTED.CDREGIAO,
       INSERTED.CDFORNECED,
       INSERTED.CDPRODUTO,
       INSERTED.DTINIVALITM,
       INSERTED.DTFINVALITM,
       INSERTED.VRPRECUNIITM,
       DELETED.VRPRECUNIITM,
       INSERTED.IDITMLISPREC,
       INSERTED.NRCOLEORIGIC,
       INSERTED.DTINCLITMCOL,
       INSERTED.IDATUREGIINC,
       INSERTED.IDATUREGIALT,
       INSERTED.CDOPERINCL,
       INSERTED.IDATUFORNINC,
       INSERTED.IDATUFORNALT
     FROM
       INSERTED,
       DELETED
     WHERE
       INSERTED.CDFILIAL    = DELETED.CDFILIAL    AND
       INSERTED.NRCOLEPRECO = DELETED.NRCOLEPRECO AND
       INSERTED.CDREGIAO    = DELETED.CDREGIAO    AND
       INSERTED.CDFORNECED  = DELETED.CDFORNECED  AND
       INSERTED.CDPRODUTO   = DELETED.CDPRODUTO   AND
       INSERTED.CDMARCA     = DELETED.CDMARCA

     UNION ALL

     SELECT
       'I' IDCOMANDO,
       CDFILIAL,
       NRCOLEPRECO,
       CDMARCA,
       CDREGIAO,
       CDFORNECED,
       CDPRODUTO,
       DTINIVALITM,
       DTFINVALITM,
       VRPRECUNIITM,
       VRPRECUNIITM,
       IDITMLISPREC,
       NRCOLEORIGIC,
       DTINCLITMCOL,
       IDATUREGIINC,
       IDATUREGIALT,
       CDOPERINCL,
       IDATUFORNINC,
       IDATUFORNALT
     FROM
       INSERTED
     WHERE
       0 = (SELECT COUNT(*) FROM DELETED)


   OPEN C_DADOS;
   FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                @V_CDFILIAL,
                                @V_NRCOLEPRECO,
                                @V_CDMARCA,
                                @V_CDREGIAO,
                                @V_CDFORNECED,
                                @V_CDPRODUTO,
                                @V_DTINIVALITM,
                                @V_DTFINVALITM,
                                @V_NEW_VRPRECUNIITM,
                                @V_OLD_VRPRECUNIITM,
                                @V_IDITMLISPREC,
                                @V_NRCOLEORIGIC,
                                @V_DTINCLITMCOL,
                                @V_IDATUREGIINC,
                                @V_IDATUREGIALT,
                                @V_CDOPERINCL,
                                @V_IDATUFORNINC,
                                @V_IDATUFORNALT;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_IDGRAVLOGCOT = 'SSS';
      SELECT @V_IDGRAVLOGCOT = ISNULL(MAX(IDGRAVLOGCOT), 'SSS')
      FROM PARASUPRI
      WHERE CDFILIAL = @V_CDFILIAL;

      SET @V_DSREMOTEADDR = 'VIA BD';
      SET @V_DSREMOTEHOST = 'VIA BD';
      SET @V_DSSERVERRDM  = 'VIA BD';
      SET @V_DSMETUSULIC  = 'VIA BD';
      SET @V_CDOPERLIC    = 'VIA BD';
      SELECT @V_DSREMOTEADDR = ISNULL(MAX(DSREMOTEADDR), 'VIA BD'),
             @V_DSREMOTEHOST = ISNULL(MAX(DSREMOTEHOST), 'VIA BD'),
             @V_DSSERVERRDM  = ISNULL(MAX(DSSERVERRDM),  'VIA BD'),
             @V_DSMETUSULIC  = ISNULL(MAX(DSSERVMETHOD), 'VIA BD'),
             @V_CDOPERLIC    = ISNULL(MAX(DSREMOTEOPER), 'VIA BD')
      FROM SQLWEBTUNNING
      WHERE NRAUDSID = @@SPID AND
            CONVERT(DATETIME, CONVERT(VARCHAR, DTSTARTDATE, 103))  =
                         (SELECT MAX(DTSTARTDATE)
                                  FROM SQLWEBTUNNING S
                                  WHERE S.NRAUDSID = @@SPID);

      IF @V_IDCOMANDO = 'I' BEGIN

         IF @V_NEW_VRPRECUNIITM = 0 BEGIN
            INSERT INTO LOGITEMCOLE
            (CDFILIALLIC,  NRCOLEPRELIC, CDMARCALIC,
             CDREGIAOLIC,  CDFORNECELIC, CDPRODUTOLIC,
             DTINIVALLIC,  DTFINVALLIC,  VRPRECANTLIC,
             VRPRECDEPLIC, DTOPERACLIC,  DSENDUSULIC,
             DSNMUSULIC,   DSRDMUSULIC, DSMETUSULIC, IDOPERALIC, CDOPERLIC,
             IDITMLISPLIC, NRCOLEORILIC, DTINCLITMLIC,
             IDATUREINLIC, IDATUREALLIC, CDOPERINCLIC,IDATUFOINLIC,IDATUFOALLIC)
           VALUES
            (@V_CDFILIAL,     @V_NRCOLEPRECO,  @V_CDMARCA,
             @V_CDREGIAO,     @V_CDFORNECED,   @V_CDPRODUTO,
             @V_DTINIVALITM,  @V_DTFINVALITM,  0,
             @V_NEW_VRPRECUNIITM, GETDATE(),   @V_DSREMOTEADDR,
             @V_DSREMOTEHOST, @V_DSSERVERRDM,  @V_DSMETUSULIC,  'I', @V_CDOPERLIC,
             @V_IDITMLISPREC, @V_NRCOLEORIGIC, @V_DTINCLITMCOL,
             @V_IDATUREGIINC, @V_IDATUREGIALT, @V_CDOPERINCL, @V_IDATUFORNINC,@V_IDATUFORNALT);
          END;

      END;

      IF @V_IDCOMANDO = 'U' BEGIN

         IF SUBSTRING(@V_IDGRAVLOGCOT, 2, 1) = 'S' BEGIN

            IF @V_NEW_VRPRECUNIITM <> @V_OLD_VRPRECUNIITM BEGIN

               INSERT INTO LOGITEMCOLE
                (CDFILIALLIC,  NRCOLEPRELIC, CDMARCALIC,
                 CDREGIAOLIC,  CDFORNECELIC, CDPRODUTOLIC,
                 DTINIVALLIC,  DTFINVALLIC,  VRPRECANTLIC,
                 VRPRECDEPLIC, DTOPERACLIC,  DSENDUSULIC,
                 DSNMUSULIC,   DSRDMUSULIC,  DSMETUSULIC, IDOPERALIC, CDOPERLIC,
                 IDITMLISPLIC, NRCOLEORILIC, DTINCLITMLIC,
                 IDATUREINLIC, IDATUREALLIC, CDOPERINCLIC,IDATUFOINLIC,IDATUFOALLIC)
               VALUES
                (@V_CDFILIAL,         @V_NRCOLEPRECO,  @V_CDMARCA,
                 @V_CDREGIAO,         @V_CDFORNECED,   @V_CDPRODUTO,
                 @V_DTINIVALITM,      @V_DTFINVALITM,  @V_OLD_VRPRECUNIITM,
                 @V_NEW_VRPRECUNIITM, GETDATE(),       @V_DSREMOTEADDR,
                 @V_DSREMOTEHOST,     @V_DSSERVERRDM,  @V_DSMETUSULIC,  'A', @V_CDOPERLIC,
                 @V_IDITMLISPREC,     @V_NRCOLEORIGIC, @V_DTINCLITMCOL,
                 @V_IDATUREGIINC,     @V_IDATUREGIALT, @V_CDOPERINCL, @V_IDATUFORNINC, @V_IDATUFORNALT);

            END;

         END;

      END;

      IF @V_IDCOMANDO = 'D' BEGIN

         IF SUBSTRING(@V_IDGRAVLOGCOT, 3, 1) = 'S' BEGIN

            INSERT INTO LOGITEMCOLE
             (CDFILIALLIC,  NRCOLEPRELIC, CDMARCALIC,
              CDREGIAOLIC,  CDFORNECELIC, CDPRODUTOLIC,
              DTINIVALLIC,  DTFINVALLIC,  VRPRECANTLIC,
              VRPRECDEPLIC, DTOPERACLIC,  DSENDUSULIC,
              DSNMUSULIC,   DSRDMUSULIC,  DSMETUSULIC, IDOPERALIC, CDOPERLIC,
              IDITMLISPLIC, NRCOLEORILIC, DTINCLITMLIC,
              IDATUREINLIC, IDATUREALLIC, CDOPERINCLIC, IDATUFOINLIC,IDATUFOALLIC)
            VALUES
             (@V_CDFILIAL,      @V_NRCOLEPRECO,   @V_CDMARCA,
              @V_CDREGIAO,      @V_CDFORNECED,    @V_CDPRODUTO,
              @V_DTINIVALITM,   @V_DTFINVALITM,   @V_NEW_VRPRECUNIITM,
              0,                GETDATE(),        @V_DSREMOTEADDR,
              @V_DSREMOTEHOST,  @V_DSSERVERRDM,   @V_DSMETUSULIC, 'E', @V_CDOPERLIC,
              @V_IDITMLISPREC,  @V_NRCOLEORIGIC,  @V_DTINCLITMCOL,
              @V_IDATUREGIINC,  @V_IDATUREGIALT,  @V_CDOPERINCL, @V_IDATUFORNINC, @V_IDATUFORNALT);

         END;

      END;

      FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                   @V_CDFILIAL,
                                   @V_NRCOLEPRECO,
                                   @V_CDMARCA,
                                   @V_CDREGIAO,
                                   @V_CDFORNECED,
                                   @V_CDPRODUTO,
                                   @V_DTINIVALITM,
                                   @V_DTFINVALITM,
                                   @V_NEW_VRPRECUNIITM,
                                   @V_OLD_VRPRECUNIITM,
                                   @V_IDITMLISPREC,
                                   @V_NRCOLEORIGIC,
                                   @V_DTINCLITMCOL,
                                   @V_IDATUREGIINC,
                                   @V_IDATUREGIALT,
                                   @V_CDOPERINCL,
                                   @V_IDATUFORNINC,
                                   @V_IDATUFORNALT;
   END;
   CLOSE C_DADOS;
   DEALLOCATE C_DADOS;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'GRAVA_LOGITEMCOLE','4.07.051';
GO

